<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'دمج TextWheel في SPIP',
	'tw_slogan' => 'إدارة الكتابة في SPIP بواسطة TextWheel',
];
